summaryrefslogtreecommitdiffstats
path: root/siplib/descriptors.c
diff options
context:
space:
mode:
Diffstat (limited to 'siplib/descriptors.c')
-rw-r--r--siplib/descriptors.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/siplib/descriptors.c b/siplib/descriptors.c
index 29277c5..009a03e 100644
--- a/siplib/descriptors.c
+++ b/siplib/descriptors.c
@@ -3,23 +3,23 @@
*
* Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
*
* This file is part of SIP.
*
- * This copy of SIP is licensed for use under the terms of the SIP License
+ * This copy of SIP-TQt is licensed for use under the terms of the SIP License
* Agreement. See the file LICENSE for more details.
*
* This copy of SIP may also used under the terms of the GNU General Public
* License v2 or v3 as published by the Free Software Foundation which can be
* found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
*
* SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/
#include <Python.h>
-#include "sip.h"
+#include "sip-tqt.h"
#include "sipint.h"
@@ -51,7 +51,7 @@ typedef struct _sipMethodDescr {
*/
PyTypeObject sipMethodDescr_Type = {
PyVarObject_HEAD_INIT(NULL, 0)
- "sip.methoddescriptor", /* tp_name */
+ "sip_tqt.methoddescriptor", /* tp_name */
sizeof (sipMethodDescr), /* tp_basicsize */
0, /* tp_itemsize */
0, /* tp_dealloc */
@@ -168,7 +168,7 @@ typedef struct _sipVariableDescr {
*/
PyTypeObject sipVariableDescr_Type = {
PyVarObject_HEAD_INIT(NULL, 0)
- "sip.variabledescriptor", /* tp_name */
+ "sip_tqt.variabledescriptor", /* tp_name */
sizeof (sipVariableDescr), /* tp_basicsize */
0, /* tp_itemsize */
0, /* tp_dealloc */
@@ -3,23 +3,23 @@
* Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
*
- * This file is part of SIP.
+ * This file is part of SIP-TQt.
*
@@ -3,23 +3,23 @@
* Agreement. See the file LICENSE for more details.
*
- * This copy of SIP may also used under the terms of the GNU General Public
+ * This copy of SIP-TQt may also used under the terms of the GNU General Public
* License v2 or v3 as published by the Free Software Foundation which can be
* found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
@@ -3,23 +3,23 @@
* found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
*
- * SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
+ * SIP-TQt is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/